@@ -67,7 +67,7 @@ sub getvalue {
 	# A value should be defined as:
 	# NAME='VALUE'
 	#
-	my $line=`grep '$name=' configure.ac`;
+	my $line=`grep "$name=" configure.ac`;
 	($value) = $line =~ /^$name='(.*)'$/;
 	unless ($value) {
 		print STDERR "$name not found.\n";
@@ -83,11 +83,11 @@ sub langmapstatement {
 	my(@statement);
 	my %name = (
 		'c'	=> 'C',
-		'yacc'	=> 'yacc',
-		'asm'	=> 'Assembly',
+		'yacc'	=> 'Yacc',
 		'java'	=> 'Java',
 		'cpp'	=> 'C++',
 		'php'	=> 'PHP',
+		'asm'	=> 'assembly language',
 	);
 	my $line = '';
 	my @maps = split(/,/, $maps);
@@ -103,7 +103,7 @@ sub langmapstatement {
 		}
 		$line .= $name{$lang};
 	}
-	$line .= " source files are supported.\n";
+	$line .= " source files.\n";
 	unshift(@statement, $line);
 	foreach (@maps) {
 		my($lang, $suffixes) = /([^:]+):(.*)/;
@@ -161,7 +161,7 @@ sub ungetline {
 package c;
 sub convert {
 	local($arg) = '[^},]+';
-	local($macros) = 'arg|code|var|file|name|option';
+	local($macros) = 'arg|code|var|file|name|option|val|samp|kbd';
 	chop;
 	s/^\s+//;
 	while (s/\@($macros)\{($arg)\}/$2/) {
@@ -170,6 +170,9 @@ sub convert {
 	while (s/\@xref\{($arg),($arg)\}/$1($2)/) {
 		;
 	}
+	while (s/\@(begin|end)_verbatim//) {
+		;
+	}
 }
 sub gen {
 	local($help_const) = 0;
@@ -263,9 +266,11 @@ sub convert {
 	while (s/\@xref\{($arg),($arg)\}/\\fB$1\\fP($2)/) {
 		;
 	}
-	s/\@{/{/g;
-	s/\@}/}/g;
+	s/\@\{/\{/g;
+	s/\@\}/\}/g;
 	s/\@br$/\n.br/;
+	s/\@\@/@/g;
+	s/^\./\\&./;
 }
 sub gen {
 	local($arg) = '[^,]+';
@@ -391,6 +396,7 @@ sub gen {
 				} elsif ($verbatim) {
 					s/\{/@\{/g;
 					s/\}/@\}/g;
+					s/^\s+//;
 					print;
 					next;
 				} elsif (/^\@/) {
