@@ -30,12 +30,10 @@
  DAMAGE. 
  =========================================================================*/
 
-/** @file
+/*
  *	get a file's base name from its path name
  */
 
-static char const rcsid[] = "$Id: basename.c,v 1.2 2012/10/13 07:01:58 shigio Exp $";
-
 #include "global-cscope.h"
 
 char *
