@@ -30,7 +30,7 @@
  DAMAGE. 
  =========================================================================*/
 
-/** @file
+/*
  *	process execution functions
  *
  *	cscope - interactive C symbol cross-reference
@@ -56,11 +56,9 @@
 #define HAVE_FORK 1
 #endif
 
-static char const rcsid[] = "$Id: exec.c,v 1.4 2014/11/27 08:21:10 shigio Exp $";
-
 static	sighandler_t oldsigquit; /**< old value of quit signal */
 static	sighandler_t oldsighup; /**< old value of hangup signal */
-static	sighandler_t oldsigtstp; /**< old value of @VAR{SIGTSTP} */
+static	sighandler_t oldsigtstp; /**< old value of SIGTSTP */
 
 #if HAVE_FORK /* none of these is needed, there */
 static	int	join(pid_t p);
@@ -117,8 +115,8 @@ execute(char *a, ...)	/* note: "exec" is already defined on u370 */
 
 #if HAVE_FORK /* None of the following functions is used there */
 
-/** myexecvp is an interface to the @NAME{execvp} system call to
- * modify @CODE{argv[0]} to reference the last component of its path-name.
+/** myexecvp is an interface to the execvp system call to
+ * modify argv[0] to reference the last component of its path-name.
  */
 static int
 myexecvp(char *a, char **args)
@@ -135,6 +133,7 @@ myexecvp(char *a, char **args)
     askforreturn();		/* wait until the user sees the message */
     myexit(1);		/* exit the child */
     /* NOTREACHED */
+    return -1;		/* to satisfy a compiler */
 }
 
 /** myfork acts like fork but also handles signals */
