@@ -1,4 +1,4 @@
-#!/opt/local/bin/python
+#!/usr/bin/env python
 #
 # Copyright (c) 2014
 #	Yoshitaro Makise
@@ -27,7 +27,7 @@ import optparse
 import pygments.lexers
 from pygments.token import Token
 
-EXUBERANT_CTAGS = "/opt/local/bin/ctags"
+EXUBERANT_CTAGS = "/usr/local/bin/ctags"
 
 # In most cases, lexers can be looked up with lowercase form of formal
 # language names. This dictionary defines exceptions.
@@ -111,7 +111,10 @@ class PygmentsParser:
 
     def get_lexer_by_langmap(self, path):
         ext = os.path.splitext(path)[1]
-        lang = self.langmap[ext]
+        if sys.platform == 'win32':
+            lang = self.langmap.get(ext.lower(), None)
+        else:
+            lang = self.langmap.get(ext, None)
         if lang:
             name = lang.lower()
             if name in LANGUAGE_ALIASES:
@@ -189,10 +192,10 @@ def parse_langmap(string):
         if not lang[0].islower():  # skip lowercase, that is for builtin parser
             for ext in exts.split('.'):
                 if ext:
-                    langmap['.' + ext] = lang
                     if sys.platform == 'win32':
-                        langmap['.' + ext.upper()] = lang
                         langmap['.' + ext.lower()] = lang
+                    else:
+                        langmap['.' + ext] = lang
     return langmap
 
 def handle_requests(langmap, options):
